@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,20 +17,21 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#ifndef CALLBACK_MANAGER_H
-#define CALLBACK_MANAGER_H
+#ifndef CALLBACK_MANAGER_HPP
+#define CALLBACK_MANAGER_HPP
 
 #include <vector>
 #include "btBulletDynamicsCommon.h"
 #include "callback.hpp"
-#include "moving_physics.hpp"
+
+class MovingPhysics;
 
 // It might actually be enough to have only two different values: track (which
 // get deleted and loaded more than one), and everything else, which only
 // gets loaded once, and deleted at the end (and when switching windows /
 // fullscreen). Sinace it's not much overhead, a separate class is provided
 // for every model that might contain a callback.
-enum CallbackType { CB_COLLECTABLE, CB_ATTACHMENT, CB_EXPLOSION, CB_HERRING,
+enum CallbackType { CB_COLLECTABLE, CB_ATTACHMENT, CB_EXPLOSION, CB_ITEM,
                     CB_KART,        CB_TRACK,      CB_MAX                    };
 
 class CallbackManager
