@@ -1,11 +1,11 @@
-//  $Id: config_display.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: config_display.cpp 3083 2009-01-30 04:56:50Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,23 +18,26 @@
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "config_display.hpp"
-#include "widget_manager.hpp"
-#include "user_config.hpp"
-#include "menu_manager.hpp"
-#include "sdldrv.hpp"
-#include "translation.hpp"
-
 #include <algorithm>
 
 #if defined(WIN32) && !defined(__CYGWIN__)
 #  define snprintf _snprintf
 #endif
 
+#include "main_loop.hpp"
+#include "widget_manager.hpp"
+#include "user_config.hpp"
+#include "menu_manager.hpp"
+#include "sdldrv.hpp"
+#include "utils/translation.hpp"
+
+
 enum WidgetTokens
 {
     WTOK_TITLE,
 
     WTOK_FULLSCREEN,
+    WTOK_NEXT_BACKGROUND,
     WTOK_INCR_RES,
     WTOK_DECR_RES,
     WTOK_CURRENT_RES,
@@ -53,7 +56,8 @@ ConfigDisplay::ConfigDisplay()
 
     widget_manager->switchOrder();
     widget_manager->addTitleWgt( WTOK_TITLE, 60, 7, _("Display Settings"));
-
+    widget_manager->hideWgtRect(WTOK_TITLE);
+    
     if( isBlacklisted( m_curr_width, m_curr_height ))
     {
         widget_manager->addEmptyWgt( WTOK_FULLSCREEN, 1, 7);
@@ -77,11 +81,14 @@ ConfigDisplay::ConfigDisplay()
         }
     }
 
+    widget_manager->addTextButtonWgt(WTOK_NEXT_BACKGROUND, 60, 7, _("Next background"));
     widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 60, 2 );
 
     char msg [MAX_MESSAGE_LENGTH];
+    //I18N: displays current resolution
     snprintf( msg, MAX_MESSAGE_LENGTH, _("Current: %dx%d"), m_curr_width, m_curr_height );
     widget_manager->addTextWgt( WTOK_CURRENT_RES, 60, 7, msg);
+    widget_manager->hideWgtRect(WTOK_CURRENT_RES);
 
     widget_manager->addTextButtonWgt( WTOK_INCR_RES, 60, 7,
         _("Increase Resolution"));
@@ -123,13 +130,27 @@ void ConfigDisplay::select()
         }
         else
         {
+#if defined(WIN32) ||defined(__CYGWIN__)
+            // Problem: on windows the textures etc. are deleted
+            // so we have to reload this object again (since all display
+            // lists in the widget were deleted). So we force to re-create
+            // this object by first pushing it from the menu stack, and
+            // then adding it again.
+            menu_manager->popMenu();
+            menu_manager->pushMenu(MENUID_CONFIG_DISPLAY);
+            return;
+#else
             //FIXME: maybe instead of 'Fullscreen mode' something like
             //'Switch to fullscreen mode' would be more user friendly?
             widget_manager->setWgtText(WTOK_FULLSCREEN, _("Fullscreen mode"));
+#endif
         }
         changeApplyButton();
         break;
-
+    case WTOK_NEXT_BACKGROUND:
+        user_config->nextBackgroundIndex();
+        main_loop->loadBackgroundImages();
+        break;
     case WTOK_INCR_RES:
         {
             const int NUM_RES = (int)m_sizes.size();
@@ -403,15 +424,15 @@ void ConfigDisplay::loadDefaultModes()
 {
     m_sizes.clear();
 
-    m_sizes.push_back( std::pair <int, int> (800, 600) );
-    m_sizes.push_back( std::pair <int, int> (1024, 768) );
-    m_sizes.push_back( std::pair <int, int> (1152, 864) );
-    m_sizes.push_back( std::pair <int, int> (1280, 768) );
-    m_sizes.push_back( std::pair <int, int> (1280, 800) );
-    m_sizes.push_back( std::pair <int, int> (1280, 960) );
-    m_sizes.push_back( std::pair <int, int> (1280, 1024) );
-    m_sizes.push_back( std::pair <int, int> (1440, 900) );
-    m_sizes.push_back( std::pair <int, int> (1680, 1050) );
-    m_sizes.push_back( std::pair <int, int> (1920, 1200) );
+    m_sizes.push_back( std::pair <int, int> (800, 600) );  // 4:3
+    m_sizes.push_back( std::pair <int, int> (1024, 768) ); // 4:3
+    m_sizes.push_back( std::pair <int, int> (1152, 864) ); // 4:3
+    m_sizes.push_back( std::pair <int, int> (1280, 768) ); // 5:3
+    m_sizes.push_back( std::pair <int, int> (1280, 800) ); // 8:5
+    m_sizes.push_back( std::pair <int, int> (1280, 960) ); // 4:3
+    m_sizes.push_back( std::pair <int, int> (1280, 1024) );// 5:4
+    m_sizes.push_back( std::pair <int, int> (1440, 900) ); // 8:5
+    m_sizes.push_back( std::pair <int, int> (1680, 1050) );// 8:5
+    m_sizes.push_back( std::pair <int, int> (1920, 1200) );// 8:5
 };
 
