@@ -1,11 +1,11 @@
-//  $Id: display_res_confirm.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: display_res_confirm.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2008 Paul Elms
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,12 +20,12 @@
 #include <iostream>
 #include <sstream>
 
-#include "display_res_confirm.hpp"
-#include "menu_manager.hpp"
-#include "widget_manager.hpp"
-#include "translation.hpp"
 #include "user_config.hpp"
 #include "sdldrv.hpp"
+#include "gui/display_res_confirm.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "utils/translation.hpp"
 
 
 #if defined(WIN32) && !defined(__CYGWIN__)
@@ -49,7 +49,8 @@ DisplayResConfirm::DisplayResConfirm( const bool FROM_WINDOW_ ) :
     widget_manager->switchOrder();
     widget_manager->addTitleWgt( WTOK_TITLE, 70, 7,
         _("Confirm Resolution Within 5 Seconds"));
-
+    widget_manager->hideWgtRect(WTOK_TITLE);
+    
     widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, 40, 2);
 
     widget_manager->addTextButtonWgt( WTOK_APPLY_RES, 40, 7, _("Confirm Resolution") );
