@@ -1,11 +1,11 @@
-// $Id: grand_prix_ending.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+// $Id: grand_prix_ending.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 Eduardo Hernandez Munoz
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,29 +17,30 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+#include "gui/grand_prix_ending.hpp"
+
 #include <sstream>
 #include <string>
+#if defined(WIN32) && !defined(__CYGWIN__)
+#  define snprintf _snprintf
+#endif
 
 #include <SDL/SDL.h>
 
 #include "loader.hpp"
-#include "sound_manager.hpp"
-#include "grand_prix_ending.hpp"
-#include "kart_properties_manager.hpp"
-#include "unlock_manager.hpp"
-#include "widget_manager.hpp"
 #include "race_manager.hpp"
-#include "game_manager.hpp"
 #include "user_config.hpp"
-#include "menu_manager.hpp"
-#include "kart_properties.hpp"
-#include "translation.hpp"
-#include "kart.hpp"
-#include "world.hpp"
-#include "scene.hpp"
-#if defined(WIN32) && !defined(__CYGWIN__)
-#  define snprintf _snprintf
-#endif
+#include "audio/sfx_manager.hpp"
+#include "audio/sfx_base.hpp"
+#include "challenges/unlock_manager.hpp"
+#include "graphics/scene.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "karts/kart.hpp"
+#include "karts/kart_model.hpp"
+#include "karts/kart_properties.hpp"
+#include "karts/kart_properties_manager.hpp"
+#include "utils/translation.hpp"
 
 enum WidgetTokens
 {
@@ -49,10 +50,11 @@ enum WidgetTokens
     WTOK_FIRSTKART
 };
 
-
+// ----------------------------------------------------------------------------
 GrandPrixEnd::GrandPrixEnd()
         : m_kart(0)
 {
+    m_winner_sound = sfx_manager->newSFX(SFXManager::SOUND_WINNER);
     // for some strange reasons plib calls makeCurrent() in ssgContext
     // constructor, so we have to save the old one here and restore it
     ssgContext* oldContext = ssgGetCurrentContext();
@@ -61,50 +63,25 @@ GrandPrixEnd::GrandPrixEnd()
 
     const unsigned int MAX_STR_LEN = 60;
     const unsigned int NUM_KARTS = race_manager->getNumKarts();
-
-    int *scores   = new int[NUM_KARTS];
-    int *position = new int[NUM_KARTS];
-    double *race_time = new double[NUM_KARTS];
-    for( unsigned int kart_id = 0; kart_id < NUM_KARTS; ++kart_id )
+    
+    // Ignore the first kart if it's a follow-the-leader race.
+    int start=(race_manager->getMinorMode()==RaceManager::MINOR_MODE_FOLLOW_LEADER) ? 1 : 0;
+    
+    
+    int winner_kart_id = -1;
+    // find which kart ended at rank '0'
+    for(unsigned int j=start; j < NUM_KARTS; ++j)
     {
-        position[kart_id]  = kart_id;
-        scores[kart_id]    = race_manager->getKartScore(kart_id);
-        race_time[kart_id] = race_manager->getOverallTime(kart_id);
-    }
-
-    //Bubblesort
-    bool sorted;
-    do
-    {
-        sorted = true;
-        for( unsigned int i = 0; i < NUM_KARTS - 1; ++i )
+        if( race_manager->getKartFinalGPRank(j) == 0 )
         {
-            if( scores[i] < scores[i+1] || (scores[i] == scores[i+1] 
-              && race_time[i] > race_time[i+1]))
-            {
-                int tmp_score[2];
-                double tmp_time;
-
-                tmp_score[0] = position[i];
-                tmp_score[1] = scores[i];
-                tmp_time = race_time[i];
-
-                position[i] = position[i+1];
-                scores[i] = scores[i+1];
-                race_time[i] = race_time[i+1];
-
-                position[i+1] = tmp_score[0];
-                scores[i+1] = tmp_score[1];
-                race_time[i+1] = tmp_time;
-
-                sorted = false;
-            }
+            winner_kart_id = j;
+            break;
         }
-    } while(!sorted);
+    }
     
     static char output[MAX_MESSAGE_LENGTH];
     snprintf(output, sizeof(output),
-        _("The winner is %s!"),race_manager->getKartName(position[0]).c_str());
+        _("The winner is %s!"),race_manager->getKartName(winner_kart_id).c_str()); // FIXME - uses inner-name and not user name
     widget_manager->addWgt( WTOK_TITLE, 60, 10);
     widget_manager->showWgtRect(WTOK_TITLE);
     widget_manager->showWgtText(WTOK_TITLE);
@@ -114,26 +91,39 @@ GrandPrixEnd::GrandPrixEnd()
 
     m_score = new char[MAX_STR_LEN*NUM_KARTS];
 
-    for(unsigned int i=0; i < NUM_KARTS; ++i)
+    for(unsigned int i=start; i < NUM_KARTS; ++i)
     {
-        char sTime[20];
-        TimeToString(race_time[i], sTime);
-        sprintf((char*)(m_score + MAX_STR_LEN * i), "%d. %s %d %s",
-            i + 1, race_manager->getKartName(position[i]).c_str(), scores[i], sTime );
-
+       // char sTime[20];sTime[0]=0;
+       // if(RaceManager::isLinearRaceMode(race_manager->getMinorMode()) &&
+       //    RaceManager::modeHasLaps(race_manager->getMinorMode()) )
+       //     TimeToString(race_time[i], sTime);
+        
+        int this_kart_id = -1;
+        // find which kart ended at rank 'i'
+        for(unsigned int j=start; j < NUM_KARTS; ++j)
+        {
+            if( (int)race_manager->getKartFinalGPRank(j) == (int)(i-start) )
+            {
+                this_kart_id = j;
+                break;
+            }
+        }
+        
+        sprintf((char*)(m_score + MAX_STR_LEN * i), "#%d (%d) : %s",
+            i-start + 1 /* add 1 because, while the inner ranks start at 0, users expect them to start at 1 */,
+            race_manager->getKartScore(this_kart_id),
+            race_manager->getKartName(this_kart_id).c_str() );
+        
         widget_manager->addWgt(WTOK_FIRSTKART + i, 40, 5);
         widget_manager->showWgtRect(WTOK_FIRSTKART + i);
         widget_manager->showWgtText(WTOK_FIRSTKART + i);
         widget_manager->setWgtText(WTOK_FIRSTKART + i,
             (char*)(m_score + MAX_STR_LEN * i));
         widget_manager->setWgtTextSize(WTOK_FIRSTKART + i, WGT_FNT_SML);
-    widget_manager->breakLine();
+        widget_manager->breakLine();
     }
-    const std::string KART_NAME = race_manager->getKartName(position[0]);
-    const KartProperties* WINNING_KART = kart_properties_manager->getKart(KART_NAME);
-    delete []scores;
-    delete []position;
-    delete []race_time;
+    const std::string WINNER_KART_NAME = race_manager->getKartName(winner_kart_id);
+    const KartProperties* WINNING_KART = kart_properties_manager->getKart(WINNER_KART_NAME);
 
     widget_manager->addWgt(WTOK_QUIT, 50, 7);
     widget_manager->activateWgt(WTOK_QUIT);
@@ -152,18 +142,17 @@ GrandPrixEnd::GrandPrixEnd()
 
     m_kart = new ssgTransform;
     m_kart->ref();
-    ssgEntity* kartentity = WINNING_KART->getModel();
-    m_kart->addKid(kartentity);
+    KartModel* kartentity = WINNING_KART->getKartModel();
+    m_kart->addKid(kartentity->getRoot());
 
-    sound_manager->playSfx(SOUND_WINNER);
+    m_winner_sound->play();
 
     m_clock = 0;
 
     //FIXME: this is taken from RaceMode::exit_race,
     //this should be organized better.
     scene->clear();
-    delete world;
-    world = 0;
+    RaceManager::setWorld(NULL);
     race_manager->m_active_race = false;
 
 }
@@ -171,6 +160,7 @@ GrandPrixEnd::GrandPrixEnd()
 //-----------------------------------------------------------------------------
 GrandPrixEnd::~GrandPrixEnd()
 {
+    sfx_manager->deleteSFX(m_winner_sound);
     widget_manager->reset();
     ssgDeRefDelete(m_kart);
 
