@@ -1,11 +1,11 @@
-//  $Id: main_menu.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: main_menu.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,20 +17,23 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+#include "gui/main_menu.hpp"
+
 #include <SDL/SDL.h>
 
-#include "main_menu.hpp"
-#include "widget_manager.hpp"
 #include "race_manager.hpp"
-#include "menu_manager.hpp"
-#include "translation.hpp"
 #include "user_config.hpp"
-#include "unlock_manager.hpp"
+#include "challenges/unlock_manager.hpp"
+#include "gui/menu_manager.hpp"
+#include "gui/widget_manager.hpp"
+#include "network/network_manager.hpp"
+#include "utils/translation.hpp"
 
 enum WidgetTokens
 {
     WTOK_SINGLE,
     WTOK_MULTI,
+    WTOK_NETWORK,
     WTOK_CHALLENGES,
     WTOK_OPTIONS,
     WTOK_QUIT,
@@ -43,34 +46,42 @@ MainMenu::MainMenu()
 {
     widget_manager->switchOrder();
 
+    // Only allow challenges if not networking for now!
+    std::vector<const Challenge*> all_challenges=unlock_manager->getActiveChallenges();
+    const bool challenges_active = all_challenges.size()>0 && network_manager->getMode()==NetworkManager::NW_NONE;
+    
     const int WIDTH=30;
     widget_manager->addTextButtonWgt( WTOK_SINGLE, WIDTH, 7, _("Single Player") );
-    widget_manager->addTextButtonWgt( WTOK_MULTI, WIDTH, 7, _("Multiplayer") );
+    widget_manager->addTextButtonWgt( WTOK_MULTI, WIDTH, 7, _("Splitscreen") );
 
-    std::vector<const Challenge*> all_challenges=unlock_manager->getActiveChallenges();
-    if(all_challenges.size()>0)
-    {
+    // Only display the networking entry when not already connected (and networking is enabled)
+    if(network_manager->getMode()==NetworkManager::NW_NONE && stk_config->m_enable_networking)
+        widget_manager->addTextButtonWgt( WTOK_NETWORK, WIDTH, 7, _("Networking") );
+
+    if(challenges_active)
         widget_manager->addTextButtonWgt( WTOK_CHALLENGES, WIDTH, 7, _("Challenges") );
-    }
 
     widget_manager->addTextButtonWgt( WTOK_OPTIONS, WIDTH, 7, _("Options") );
     widget_manager->addTextButtonWgt( WTOK_QUIT, WIDTH, 7, _("Quit") );
 
-    widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, WIDTH, 7 );
+    if(user_config->getWarning()!="")
+    {
+        widget_manager->addTextWgt( WTOK_WARNING, 80, 6, user_config->getWarning().c_str() );
+        widget_manager->setWgtTextSize( WTOK_WARNING, WGT_FNT_SML );
+        widget_manager->hideWgtRect(WTOK_WARNING);
+    }
+    else
+        widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, WIDTH, 6 );
 
     widget_manager->addTextButtonWgt( WTOK_HELP, WIDTH, 7, _("Help") );
     widget_manager->setWgtTextSize( WTOK_HELP, WGT_FNT_SML );
 
     widget_manager->addTextButtonWgt( WTOK_CREDITS, WIDTH, 7, _("Credits") );
     widget_manager->setWgtTextSize( WTOK_CREDITS, WGT_FNT_SML );
+    
+    widget_manager->addEmptyWgt( WidgetManager::WGT_NONE, WIDTH, 15 );
 
-    if(user_config->getWarning()!="")
-    {
-        widget_manager->addTextWgt( WTOK_WARNING, 80, 8, user_config->getWarning().c_str() );
-        widget_manager->setWgtTextSize( WTOK_WARNING, WGT_FNT_SML );
-        widget_manager->hideWgtRect(WTOK_WARNING);
-    }
-
+    widget_manager->activateWgt(WTOK_SINGLE);
     widget_manager->layout(WGT_AREA_ALL);
 }
 
@@ -87,12 +98,25 @@ void MainMenu::select()
     switch ( widget_manager->getSelectedWgt() )
     {
     case WTOK_SINGLE:
-        race_manager->setNumPlayers(1);
-        menu_manager->pushMenu(MENUID_GAMEMODE);
+        race_manager->setNumLocalPlayers(1);
+		race_manager->setNumPlayers(1); // reset since this is used to determine the minimum number of players
+        // The clients do not do any  mode selection, they go immediately
+        // to the character selection screen.
+        if(network_manager->getMode()==NetworkManager::NW_CLIENT)
+        {
+            menu_manager->pushMenu(MENUID_CHARSEL_P1);
+        }
+        else
+        {
+            menu_manager->pushMenu(MENUID_GAMEMODE);
+        }
         break;
     case WTOK_MULTI:
         menu_manager->pushMenu(MENUID_NUMPLAYERS);
         break;
+    case WTOK_NETWORK:
+        menu_manager->pushMenu(MENUID_NETWORK_GUI);
+        break;
     case WTOK_CHALLENGES:
         menu_manager->pushMenu(MENUID_CHALLENGES);
         break;
