@@ -1,11 +1,11 @@
-//  $Id: material_manager.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: material_manager.cpp 3034 2009-01-23 05:23:22Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004 Steve Baker <sjbaker1@airmail.net>
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,17 +17,14 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#include <stdexcept>
-#include "file_manager.hpp"
 #include "material_manager.hpp"
-#include "material.hpp"
-#include "translation.hpp"
-#include "string_utils.hpp"
 
-#if defined(WIN32) && !defined(__CYGWIN__)
-#  define snprintf _snprintf
-#  define strdup _strdup
-#endif
+#include <stdexcept>
+#include <sstream>
+
+#include "file_manager.hpp"
+#include "material.hpp"
+#include "utils/string_utils.hpp"
 
 ssgState *fuzzy_gst;
 
@@ -89,15 +86,15 @@ void MaterialManager::addSharedMaterial(const std::string& filename)
     // material index later, so that these materials are not popped
     if(filename=="")
     {
-        char msg[MAX_ERROR_MESSAGE_LENGTH];
-        snprintf(msg, sizeof(msg), "FATAL: File '%s' not found\n", filename.c_str());
-        throw std::runtime_error(msg);
+        std::ostringstream msg;
+        msg<<"FATAL: File '"<<filename<<"' not found\n";
+        throw std::runtime_error(msg.str());
     }
     if(!pushTempMaterial(filename))
     {
-        char msg[MAX_ERROR_MESSAGE_LENGTH];
-        snprintf(msg, sizeof(msg), "FATAL: Parsing error in '%s'\n", filename.c_str());
-        throw std::runtime_error(msg);
+        std::ostringstream msg;
+        msg <<"FATAL: Parsing error in '"<<filename<<"'\n";
+        throw std::runtime_error(msg.str());
     }
     m_shared_material_index = (int)m_materials.size();
 }   // addSharedMaterial
@@ -195,8 +192,22 @@ Material *MaterialManager::getMaterial ( ssgLeaf *l )
 }   // getMaterial
 
 //-----------------------------------------------------------------------------
+/** Returns the material of a given name, if it doesn't exist, it is loaded.
+ *  Materials that are just loaded are not permanent, and so get deleted after
+ *  a race (this is used to load temporary, track specific materials). To make
+ *  material permanent, make_permanent must be set to true. This is used for
+ *  the powerup_manager, since not all icons for the powerups are listed in the
+ *  materials.dat file, causing the missing ones to be temporary only (and
+ *  then get deleted after one race, causing the powerup_manager to have 
+ *  invalid pointers.
+ *  \param fname  Name of the material.
+ *  \param is_full_path True if the name includes the path (defaults to false)
+ *  \param make_permanent True if this material should be kept in memory 
+ *                        (defaults to false)
+ */
 Material *MaterialManager::getMaterial(const std::string& fname, 
-                                       bool is_full_path )
+                                       bool is_full_path,
+                                       bool make_permanent)
 {
     if(fname=="")
     {
@@ -220,7 +231,7 @@ Material *MaterialManager::getMaterial(const std::string& fname,
     // Add the new material
     Material* m=new Material(fname,"", (int)m_materials.size(), is_full_path);
     m_materials.push_back(m);
-
+    if(make_permanent) m_shared_material_index = (int)m_materials.size();
     return m ;
 }   // getMaterial
 
