@@ -1,4 +1,4 @@
-//  $Id: static_ssg.cpp 2111 2008-05-31 07:04:30Z cosmosninja $
+//  $Id: static_ssg.cpp 2279 2008-09-19 06:07:29Z hikerstk $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 Joerg Henrichs
@@ -7,7 +7,7 @@
 //
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
-//  as published by the Free Software Foundation; either version 2
+//  as published by the Free Software Foundation; either version 3
 //  of the License, or (at your option) any later version.
 //
 //  This program is distribhuted in the hope that it will be useful,
@@ -18,11 +18,14 @@
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-#include <algorithm>
+
 #include "static_ssg.hpp"
+
+#include <algorithm>
+
 #include "material_manager.hpp"
 #include "material.hpp"
-#include "ssg_help.hpp"
+#include "utils/ssg_help.hpp"
 
 #ifndef round
 # define round(x)  (floor(x+0.5f))
@@ -41,7 +44,12 @@ StaticSSG::StaticSSG(ssgEntity* start_, int nSize)
 void StaticSSG::Setup(int nSize)
 {
     // First compute the minimum and maximum x/y values of all leaves
-    MinMax(m_start, &m_x_min, &m_x_max, &m_y_min, &m_y_max);
+    Vec3 min, max;
+    SSGHelp::MinMax(m_start, &min, &max);
+    m_x_min = min.getX();
+    m_x_max = max.getX();
+    m_y_min = min.getY();
+    m_y_max = max.getY();
 
     const float RATIO = (m_x_max-m_x_min)/(m_y_max-m_y_min);
 
